relatorio: Relatório NBR

Description Usage Arguments Value

View source: R/functions.R

Description

Relatório NBR

Usage

1
relatorio(link, root = "Rel_NBR")

Arguments

link

"The google sheet sharing link"

root

"The name of the root folder to store all output

Value

Several plots and tables as a result of the NBR norm.


paternogbc/NBR documentation built on Sept. 26, 2020, 5:53 p.m.