Description Usage Arguments Value
Relatório NBR
1 | relatorio(link, root = "Rel_NBR")
|
link |
"The google sheet sharing link" |
root |
"The name of the root folder to store all output |
Several plots and tables as a result of the NBR norm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.